## 2.0.0 / unreleased

- Drop support for Python 2. Use Python 3.9+ instead.
- Rename branch `master` to `main`.
- Use ruff for formatting and linting.
- Add typing information.
- Force some keyword arguments to be named.
- Switch Sphinx theme to Furo.
- Accept dialect "lorem" as alias for "ipsum"
- Fix plural form for nouns ending on -y

## 1.2.0 / 2018-01-01

- Add `num` word type.
- Add `pick` word type.
- Add lorem_tao dialect.

## 1.1.1 / 2017-09-22

- Construct plural form for nouns ending on -y

## 1.1.0 / 2017-09-07

- Support count=None for infinite generators

## 1.0.0 / 2017-08-06

- Initial release
